@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "define-it" "0.2.5"
+(define-package "define-it" "20260101.558"
   "Define, translate, wiki the word."
   '((emacs            "25.1")
     (s                "1.12.0")
@@ -10,8 +10,8 @@
     (google-translate "0.11.18")
     (wiki-summary     "0.1"))
   :url "https://github.com/jcs-elpa/define-it"
-  :commit "de026f399d5b7fa9286f7733b2e3416c6f234372"
-  :revdesc "de026f399d5b"
+  :commit "f33effcfcd4ef73cefd5d1c32991c5802269643e"
+  :revdesc "f33effcfcd4e"
   :keywords '("convenience" "dictionary" "explanation" "search" "wiki")
   :authors '(("Jen-Chieh" . "jcs090218@gmail.com"))
   :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")))
